Learn R Programming

anominate (version 0.7)

summary.anominate: alpha-NOMINATE Summary

Description

summary.anominate reads an anominate object and prints a summary.

Usage

# S3 method for anominate
summary(object, ...)

Value

A summary of an anominate object. Reports the number of legislators, votes, dimensions, and descriptive statistics for alpha.

Arguments

object

An anominate output object.

...

Other arguments do nothing and are not passed to any functions.

Author

Royce Carroll [email protected]

Christopher Hare [email protected]

Jeffrey B. Lewis [email protected]

James Lo [email protected]

Keith T. Poole [email protected]

Howard Rosenthal [email protected]

See Also

'anominate','plot.anominate','densplot.anominate','traceplot.anominate'.

Examples

Run this code
  data(sen111)
  # \donttest{
  sen111_anom <- anominate(sen111, dims=1, polarity=2, 
    nsamp=200, thin=1, burnin=100, random.starts=FALSE, 
    verbose=FALSE, constrain=FALSE)
  # }
  # 'sen111_anom' can be retrieved quickly with: 
  data(sen111_anom)
  
  summary(sen111_anom)

Run the code above in your browser using DataLab