Learn R Programming

anominate (version 0.7)

traceplot.anominate: alpha-NOMINATE Trace Plot

Description

traceplot.anominate reads an object and plots the density of sampled values of the alpha parameter using the traceplot function in coda.

Usage

# S3 method for anominate
traceplot(x, ...)

Value

A trace plot of sampled values of alpha.

Arguments

x

An anominate output object.

...

Other arguments to traceplot.

Author

Royce Carroll [email protected]

Christopher Hare [email protected]

Jeffrey B. Lewis [email protected]

James Lo [email protected]

Keith T. Poole [email protected]

Howard Rosenthal [email protected]

See Also

'anominate','summary.anominate','plot.anominate','densplot.anominate','sen111', 'sen111_anom'.

Examples

Run this code
  data(sen111)
  # \donttest{
  sen111_anom <- anominate(sen111, dims=1, polarity=2, 
    nsamp=200, thin=1, burnin=100, random.starts=FALSE, 
    verbose=FALSE, constrain=FALSE)
  # }
  # 'sen111_anom' can be retrieved quickly with: 
  data(sen111_anom)
  
  summary(sen111_anom)
  traceplot.anominate(sen111_anom)

Run the code above in your browser using DataLab